
.fieldWrapper
{
    padding-top:10px;
}

.fieldWrapper label
{
    display:inline-block;
    float:left;
    clear:left;
    width:150px;
    text-align:right;
    padding:5px;
}

.fieldWrapper .input
{
    display:inline-block;
    float:left;
    padding:5px;
}

.fieldWrapper .error
{
    float:left;
    display:inline-block;
    color:red;
    padding:5px;
}

.fieldWrapper textarea
{
    height:100px;
    width:500px;
}
.fieldWrapper a
{
    float:left;
    display:inline-block;
    padding:10px;
}

.icon
{
    width:30px;
    height:30px;
}
