<nav class="subnavbar navbar-default navbar-fixed-top">
    <div class="container">
        <div class="collapse navbar-collapse navbar-ex1-collapse">
            <ul class="nav navbar-nav">
              <li><a href="{% url "index" %}">FeedMe</a></li>
              {% if is_admin %}
              <li><a href="{% url "admin" %}">Admin</a></li>
              {% endif %}
              <li><a href="#">Bruker: {{ user.username }}</a></li>
              <li><a href="#">Saldo: {{ user.balance.get_balance }}</a></li>
              {% if not user.is_authenticated %}
              <li class="pull-right">
                  <form method="post" action="">
                      {% csrf_token %}
                      <input type="text" name="act" value="log_in" hidden>
                      <input type="text" name="username" placeholder="Username">
                      <input type="password" name="password" placeholder="********">
                      <input type="submit" name="log_in" value="Log in">
                  </form>
              </li>
              {% endif %}
            </ul>
        </div>
    </div>
</nav>
