<section name="poll">
    <h2>{{ poll.question }}</h2>
    {% if poll.result %}
        {% include 'chart.html' %}
    {% endif %}
    {% if user.is_authenticated and answer %}
        <form action="" method="POST">
            {% csrf_token %}
            <input type="text" name="act" value="vote" hidden>
            {% for field in answer %}
                {{ field }}
            {% endfor %}
            <input type="submit" value="Stem" class="btn btn-primary">
        </form>
    {% endif %}
</section>
